# graphql-utils (dev)

```bash
uv build
```

## Testing

We use `pytest` for testing, which supports unittesting and functional testing.


```bash

Run the tests using the following command:

```bash
uv run pytest
```
